values property
A Stream of all values on this view, including the current value at the time the stream is listened to.
Implementation
@override
Stream<T> get values {
late StreamController<T> controller;
controller = StreamController(onListen: () {
controller.add(value);
controller.addStream(stream).then((_) => controller.close());
});
return controller.stream;
}