hasSelectionObservers property
Returns true if a subscriber is listening to selectionChanges.
Implementation
@override
bool get hasSelectionObservers {
return _selectionChangeController != null &&
_selectionChangeController!.hasListener;
}
Returns true if a subscriber is listening to selectionChanges.
@override
bool get hasSelectionObservers {
return _selectionChangeController != null &&
_selectionChangeController!.hasListener;
}