PopupSourceDirective constructor
PopupSourceDirective(
- DomPopupSourceFactory _domPopupSourceFactory,
- HtmlElement? _element,
- @Optional.new() ReferenceDirective? _referenceDirective,
- @Optional.new() Focusable? _focusable,
- @Attribute.new('initPopupAriaAttributes') String initAriaAttributes,
initPopupAriaAttributes is an attribute input that decide whether to
set the popup related aria attributes. This defaults to true and can be
set to false for cases where the popup source isn't the focus target.
Implementation
PopupSourceDirective(
this._domPopupSourceFactory,
this._element,
@Optional() this._referenceDirective,
@Optional() this._focusable,
@Attribute('initPopupAriaAttributes') String initAriaAttributes)
: _initAriaAttributes =
attributeToBool(initAriaAttributes, defaultValue: true);