raised property
Is true if the button should have a box shadow that makes the button look
raised.
Implementation
@Input()
bool raised = false;
Is true if the button should have a box shadow that makes the button look
raised.
@Input()
bool raised = false;