disabled property

  1. @HostBinding.new('class.disabled')
  2. @HostBinding.new('attr.aria-disabled')
  3. @Input.new()
bool disabled
getter/setter pairoverride

Whether the checkbox should not respond to events, and have a style that suggests that interaction is not allowed.

Implementation

@HostBinding('class.disabled')
@HostBinding('attr.aria-disabled')
@Input()
bool disabled = false;