CalendarWeek class

A calendar week.

Constructors

CalendarWeek(Date _start, CalendarState state, [int _startingWeekday = DateTime.monday])

Properties

days List<CalendarDay>
The CalendarDay instances within this week.
no setter
hashCode int
The hash code for this object.
no setterinherited
highlights List<Highlight>
no setter
next CalendarWeek?
no setter
numBlankDays int
Blank 'spacer' days, if this is the first week of the month and the month does not start on the first day of the week. Publicly visible for tests.
no setter
numDays int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacers List
no setter

Methods

highlightsInGroup(int group) Iterable<Highlight>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(CalendarState state) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited