activeDateFormat property
- @Input.new()
getter/setter pair
The DateFormat used to format dates when the input is active.
Implementation
@Input()
late DateFormat activeDateFormat;
The DateFormat used to format dates when the input is active.
@Input()
late DateFormat activeDateFormat;