HasComparisonRange class abstract

Info needed to edit comparison ranges.

Implementers

Constructors

HasComparisonRange()

Properties

comparison ObservableReference<DateRange?>
An observable handle on the comparison range.
no setter
comparisonEnabled bool
getter/setter pair
comparisonOption ComparisonOption?
getter/setter pair
comparisonSupported bool
true if this date range type supports comparison
no setter
hashCode int
The hash code for this object.
no setterinherited
maxDate Date?
The latest date that can be chosen for comparison.
no setter
minDate Date?
The earliest date that can be chosen for comparison.
no setter
primaryRange DatepickerDateRange?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validComparisonOptions List<ComparisonOption>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited