state property

CalendarState get state

Implementation

CalendarState get state => model.value;
  1. @Input.new()
set state (CalendarState state)

An object describing the entire state of the calendar -- what's selected on the calendar, and whether or not the selection is currently "active".

Implementation

@Input()
set state(CalendarState state) {
  model.value = state;
  if (_calendarStream == null) onCalendarChange(state);
}