MaterialMonthPickerComponent class

An material-styled calendar which supports selecting single months or month ranges.

Attributes:

  • mode -- What sort of interaction this calendar supports. Valid values are "none", "single-date", or "date-range". Defaults to "none".
Annotations
  • @Component.new(changeDetection: ChangeDetectionStrategy.OnPush, selector: 'material-month-picker', styleUrls: ['material_month_picker.scss.css'], templateUrl: 'material_month_picker.html')

Constructors

MaterialMonthPickerComponent(@Optional.new() @Inject.new(datepickerClock) Clock clock, @Attribute.new('mode') String mode)

Properties

container Element
no getter
hashCode int
The hash code for this object.
no setterinherited
maxDate Date
Dates later than maxDate cannot be clicked on or scrolled to.
getter/setter pair
minDate Date
Dates earlier than minDate cannot be clicked on or scrolled to.
getter/setter pair
mode CalendarSelectionMode
What sort of interaction this calendar supports.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CalendarState
An object describing the entire state of the calendar -- what's selected on the calendar, and whether or not the selection is currently "active".
getter/setter pair
stateChange Stream<CalendarState>
Fired when the calendar state changes -- e.g. when the user starts dragging the selected date range.
no setter

Methods

ngAfterChanges() → void
ngAfterViewInit() → void
ngOnDestroy() → void
Executed before the directive is removed from the DOM and destroyed.
ngOnInit() → void
Executed after the first change detection run for a directive.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollToYear(int year) → void
Scroll the view so that year becomes visible.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited