copyWith method

Date copyWith(
  1. void updates(
    1. Date
    )
)
override

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

Date copyWith(void Function(Date) updates) =>
    super.copyWith((message) => updates(message as Date));