leadingText property
Any text to show at the leading edge of the input -- e.g. a currency symbol or similar.
Implementation
@Input()
String? leadingText;
Any text to show at the leading edge of the input -- e.g. a currency symbol or similar.
@Input()
String? leadingText;