trailingText property
Any text to show at the trailing edge of the input -- e.g. a currency symbol or similar.
Implementation
@Input()
String? trailingText;
Any text to show at the trailing edge of the input -- e.g. a currency symbol or similar.
@Input()
String? trailingText;