menuItem property
MenuItem?
get
menuItem
Implementation
MenuItem? get menuItem => _viewModel?.menuItem;
- @Input.new()
MenuItem that defines the appearance and behavior of this menu.
If the item has sub menu with no empty item groups, a menu will be surfaced via clicking or hovering.
Implementation
@Input()
set menuItem(MenuItem? menuItem) {
if (menuItem == null) return;
viewModel = MaterialFabMenuModel(menuItem, showPopup: showPopup);
}