preferredPopupPositions property
Popup positions for the menu popup to show up in.
Implementation
@Input()
List<RelativePosition>? preferredPopupPositions;
Popup positions for the menu popup to show up in.
@Input()
List<RelativePosition>? preferredPopupPositions;