preferredPositions property
Preferred positions to pass to the material popup component.
For the meaning of this parameter, see the PopupInterface documentation.
Implementation
@Input()
Iterable? preferredPositions;
Preferred positions to pass to the material popup component.
For the meaning of this parameter, see the PopupInterface documentation.
@Input()
Iterable? preferredPositions;