disabled property
- @Input.new()
- @HostBinding.new('class.disabled')
- @HostBinding.new('attr.aria-disabled')
getter/setter pairoverride
Whether the radio should not respond to events, and have a style that suggests that interaction is not allowed.
Implementation
@Input()
@HostBinding('class.disabled')
@HostBinding('attr.aria-disabled')
bool disabled = false;