tabIndex property
Current tab index, depends on state of disabled and selection status if in group.
Implementation
@HostBinding('attr.tabindex')
@visibleForTesting
@visibleForTemplate
int get tabIndex => disabled ? -1 : _enabledTabIndex;
Current tab index, depends on state of disabled and selection status if in group.
@HostBinding('attr.tabindex')
@visibleForTesting
@visibleForTemplate
int get tabIndex => disabled ? -1 : _enabledTabIndex;