buttonAriaRole property

String buttonAriaRole
final

The ARIA role to be used for the internal dropdown button.

If not provided, will use the default role for DropdownButtonComponent: 'button'.

Implementation

final String buttonAriaRole;