componentRenderer property

ComponentRenderer<RendersValue, Object> get componentRenderer
inherited

Specifies the componentRenderer to use to determine the component for rendering an item.

Implementation

@override
@Deprecated(
    'Use factoryRenderer instead it provides more tree-shakeable code')
late ComponentRenderer<RendersValue, Object> componentRenderer;
  1. @Input.new()
  2. @override
  3. @Deprecated('Use factoryRenderer it allows for more tree-shakable code.')
set componentRenderer (ComponentRenderer<RendersValue, Object> value)
override

Specifies the componentRenderer to use to determine the component for rendering an item.

Implementation

@Input()
@override
@Deprecated('Use factoryRenderer it allows for more tree-shakable code.')
set componentRenderer(ComponentRenderer<RendersValue, Object> value) {
  super.componentRenderer = value;
}