MaterialSelectItemComponent<T> class
Material Select Item is a special kind of list item which can be selected.
For accessibility, should be contained in an element with role="listbox" and aria-multiselectable set appropriately, unless role is set to something other than "option".
- Inheritance
-
- Object
- RootFocusable
- ButtonDirective
- MaterialSelectItemComponent
- Implemented types
-
- SelectionItem<
T> - HasRenderer<
T> - HasComponentRenderer<
RendersValue, dynamic> - HasFactoryRenderer<
RendersValue, T>
- SelectionItem<
- Implementers
- Annotations
-
- @Component.new(selector: 'material-select-item', providers: [ExistingProvider(SelectionItem, MaterialSelectItemComponent), ExistingProvider(HasDisabled, MaterialSelectItemComponent), ExistingProvider(HasRenderer, MaterialSelectItemComponent)], styleUrls: ['material_select_item.scss.css'], directives: [GlyphComponent, MaterialCheckboxComponent, NgIf, DynamicComponent], templateUrl: 'material_select_item.html', changeDetection: ChangeDetectionStrategy.OnPush)
Constructors
- MaterialSelectItemComponent(HtmlElement element, @Optional.new() DropdownHandle _dropdown, @Optional.new() ActivationHandler _activationHandler, ChangeDetectorRef _cdRef, @Attribute.new('role') String role, {bool addTabIndexWhenNonTabbable = false})
Properties
- ariaRole → String?
-
no setterinherited
- closeOnActivate ↔ bool
-
Whether to cause dropdown to be closed on activation.
getter/setter pair
-
componentFactory
→ ComponentFactory<
Object> ? -
no setter
-
componentRenderer
↔ ComponentRenderer<
RendersValue, dynamic> -
getter/setter pairoverride
- componentType → Type?
-
no setter
- deselectOnActivate ← bool
-
If true and selectOnActivate is true, triggering this item component will
deselect the currently selected
valuewithin the selection; if false, triggering this component whenvalueis selected will do nothing.no getter - disabled ↔ bool
-
Is the component disabled.
getter/setter pairinherited-setteroverride-getter
- disabledStr → String
-
String value to be passed to aria-disabled.
no setterinherited
- element → HtmlElement
-
final
-
factoryRenderer
↔ FactoryRenderer<
RendersValue, T> -
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideCheckbox ↔ bool
-
Whether to hide the checkbox.
getter/setter pair
- hostTabIndex → String
-
no setterinherited
- isAriaChecked → bool?
-
no setter
- isHidden ↔ bool
-
Whether the item should be hidden.
getter/setter pair
- isSelected → bool
-
Whether this item should be marked as selected.
no setter
-
itemRenderer
↔ ItemRenderer<
T> -
A function to render an item as a String.
getter/setter pairoverride
- role ↔ String?
-
Role of this component used for a11y.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected ↔ bool
-
Manually mark items selected.
getter/setter pair
-
selection
↔ SelectionModel<
T> -
The selection model this item is a member of.
getter/setter pairoverride
- selectOnActivate ← bool
-
If true, triggering this item component will select the
valuewithin the selection; if false, triggering this item component will do nothing.no getter - supportsMultiSelect → bool
-
Whether the container supports selecting multiple items.
no setter
- tabbable ↔ bool
-
Is the component tabbable.
getter/setter pairinherited
- tabIndex → String?
-
no setterinherited
- tabindex ← String
-
The tab index of the component.
no getterinherited
-
trigger
→ Stream<
UIEvent> -
Fired when the button is activated via click, tap, or key press.
no setterinherited
- useCheckMarks ↔ bool
-
If true, check marks are used instead of checkboxes to indicate whether or
not the item is selected for multi-select items.
getter/setter pair
- value ↔ T
-
The value this selection item represents.
getter/setter pairoverride
- valueHasLabel → bool
-
no setter
- valueLabel → String?
-
no setter
Methods
-
dispose(
) → void -
Disposes this disposable and any resources it has open.
inherited
-
focus(
) → void -
Item/component focuses itself
inherited
-
handleActivate(
UIEvent e) → void -
handleClick(
MouseEvent mouseEvent) → void -
Triggers if not disabled.
inherited
-
handleKeyPress(
KeyboardEvent keyboardEvent) → void -
Triggers on enter and space if not disabled.
inherited
-
ngOnDestroy(
) → void - Executed before the directive is removed from the DOM and destroyed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onLoadCustomComponent(
ComponentRef ref) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateTabIndex(
) → void -
Use this method if you want to manually compute and cache the tab index.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited