componentRenderer property
Specifies the componentRenderer to use to determine the component for rendering an item.
Implementation
@override
@Deprecated(
'Use factoryRenderer instead it provides more tree-shakeable code')
late ComponentRenderer<RendersValue, Object> componentRenderer;
- @Deprecated('Use [factoryRenderer] instead')
- @Input.new()
- @override
override
Specifies the componentRenderer to use to determine the component for rendering an item.
Implementation
@Deprecated('Use [factoryRenderer] instead')
@Input()
@override
set componentRenderer(ComponentRenderer<RendersValue, Object> value) {
super.componentRenderer = value;
}