componentRenderer property

ComponentRenderer<RendersValue, Object> get componentRenderer
inherited

Specifies the componentRenderer to use to determine the component for rendering an item.

Implementation

@override
@Deprecated(
    'Use factoryRenderer instead it provides more tree-shakeable code')
late ComponentRenderer<RendersValue, Object> componentRenderer;
  1. @Deprecated('Use [factoryRenderer] instead')
  2. @Input.new()
  3. @override
set componentRenderer (ComponentRenderer<RendersValue, Object> value)
override

Specifies the componentRenderer to use to determine the component for rendering an item.

Implementation

@Deprecated('Use [factoryRenderer] instead')
@Input()
@override
set componentRenderer(ComponentRenderer<RendersValue, Object> value) {
  super.componentRenderer = value;
}