popupPositions property

List<Object> get popupPositions

Implementation

List<Object> get popupPositions =>
    _customPopupPositions ?? _defaultPopupPositions;
  1. @Input.new()
set popupPositions (List<Object> positions)

List of positions to try and draw the options popup.

If left unset or if explicitly set to null, _defaultPopupPositions will be used. See MaterialPopupComponent for more information.

Implementation

@Input()
set popupPositions(List<Object> positions) {
  _customPopupPositions = positions;
}