selectionChange property

  1. @Output.new()
Stream get selectionChange

Emits the selected value(s) whenever selection changes.

For single select, it will either be the selected value or null. For multi select, it will a list of selected values or an empty list.

Implementation

@Output()
Stream get selectionChange {
  _selectionChangeController ??= StreamController();
  _initSelectionModel();
  return _selectionChangeController!.stream;
}