softLookup method
Like the [] operator, but does not try to fill missing indices by
deferring to _mapSource, instead returning null.
Implementation
T softLookup(int index) => _target![index] as T;
Like the [] operator, but does not try to fill missing indices by
deferring to _mapSource, instead returning null.
T softLookup(int index) => _target![index] as T;