timeZoneAwareClock top-level constant
- @Deprecated('use the TimeZoneAwareClock class instead')
See TimeZoneAwareClock.
Deprecated in favor of TimeZoneAwareClock, since having two ways to perform the same task is redundant, and since subclassing is more expressive.
Implementation
@Deprecated('use the TimeZoneAwareClock class instead')
const timeZoneAwareClock = OpaqueToken('timeZoneAwareClock');