DelegatingMenuItem<SubMenuType> class

Delegate menu item class so other classes can implement the MenuItem interface without implementing all the members.

Implemented types

Constructors

DelegatingMenuItem(MenuItem<SubMenuType> _delegate)

Properties

action MenuAction?
getter/setter pairoverride
actionWithContext ActionWithContext?
getter/setter pairoverride
ariaLabel String?
no setteroverride
cssClasses → BuiltList<String>
no setteroverride
enabled bool
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
hasIcon bool
no setteroverride
hasSecondaryLabel bool
no setteroverride
hasSubMenu bool
no setteroverride
icon Icon?
no setteroverride
itemSuffixes → ObservableList<MenuItemAffix>
no setteroverride
label String
no setteroverride
labelAnnotation String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryLabel String?
no setteroverride
showTooltip bool
no setteroverride
no setteroverride
tooltip String
no setteroverride
uiDisplayName String
no setteroverride
uiIcon Icon?
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited