MenuModel<T> class

Represents a tree-based collection of menu items.

The items are organized into MenuItemGroup instances. IMPORTANT: menu model is immutable, since menu component are OnPush.

Implemented types

Constructors

Properties

hashCode int
The hash code for this object.
no setterinherited
hasIcon bool
no setter
hasTooltip bool
True if the menu has a tooltip.
no setter
icon Icon?
Icon for the menu, can be displayed in the element opening the menu.
final
itemGroups List<MenuItemGroup<T>>
The groups of menu items. IMPORTANT this is immutable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltipText String?
final
uiIcon Icon?
no setteroverride
width int?
Selects 1 of 5 predefined width values.
getter/setter pairoverride-setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited