NullMenuItem class abstract

Type that can be specified to mark that there can be no subMenus for a given MenuItem.

Inheritance

Constructors

NullMenuItem()
factory

Properties

action MenuAction?
getter/setter pairinherited
actionWithContext ActionWithContext?
getter/setter pairinherited
ariaLabel String?
finalinherited
cssClasses → BuiltList<String>
finalinherited
enabled bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasIcon bool
no setterinherited
hasSecondaryLabel bool
no setterinherited
hasSubMenu bool
no setterinherited
icon Icon?
finalinherited
itemSuffixes → ObservableList<MenuItemAffix>
finalinherited
label String
finalinherited
labelAnnotation String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryLabel String?
finalinherited
showTooltip bool
no setterinherited
finalinherited
tooltip String
finalinherited
uiDisplayName String
no setterinherited
uiIcon Icon?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited