SelectionContainer<T> class abstract mixin

A type of component which renders items from a SelectionModel and may show options from a SelectionOptions model.

Implemented types
Implementers

Constructors

SelectionContainer()

Properties

componentRenderer ComponentRenderer<RendersValue, Object>
Specifies the componentRenderer to use to determine the component for rendering an item.
getter/setter pairoverride
factoryRenderer FactoryRenderer<RendersValue, T>
Specifies the factoryRenderer to use to determine the factory for rendering an item.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
itemRenderer ItemRenderer<T>
A simple function to render the an item to string. @override
getter/setter pairoverride
options SelectionOptions<T>
The available options for this container.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection SelectionModel<T>
The selection model this container represents.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited