OptionGroup<T>.withLabel constructor
An option group with a label is recommended when multiple option groups exist in a selection list.
Implementation
OptionGroup.withLabel(super.items, [super.label, String? emptyLabel])
: _emptyLabelFcn = emptyLabel != null ? (() => emptyLabel) : null,
super.withLabel();