panController property
Gets the pan controller for the given scroll host.
Implementation
@override
PanController get panController => _scrollHost!.panController;
Gets the pan controller for the given scroll host.
@override
PanController get panController => _scrollHost!.panController;