position property
Whether element should stick to top or bottom of sticky range.
Default is StickyPosition.top.
Implementation
@Input('stickyPosition')
set position(StickyPosition position) {
_position = position;
}
Whether element should stick to top or bottom of sticky range.
Default is StickyPosition.top.
@Input('stickyPosition')
set position(StickyPosition position) {
_position = position;
}