panController property
PanController
get
panController
Gets the pan controller for the given scroll host.
Implementation
PanController get panController;
Gets the pan controller for the given scroll host.
PanController get panController;