stickyController property
StickyController
get
stickyController
Gets the sticky controller for the given scroll host.
Implementation
StickyController get stickyController;
Gets the sticky controller for the given scroll host.
StickyController get stickyController;