onCancel property

  1. @override
FutureOr<void> Function()? get onCancel
override

The callback which is called when the stream is canceled.

May be set to null, in which case no callback will happen.

Implementation

@override
FutureOr<void> Function()? get onCancel => _initializeLazy().onCancel;
  1. @override
set onCancel (FutureOr<void> onCancelHandler()?)
override

The callback which is called when the stream is canceled.

May be set to null, in which case no callback will happen.

Implementation

@override
set onCancel(FutureOr<void> Function()? onCancelHandler) {
  _initializeLazy().onCancel = onCancelHandler;
}