attach method
Attaches portal.
Returns a future that completes when portal is attached with the context of the instantiated view. For components, this is an instance of the component. For views, it is a Map of locals.
When possible, prefer using Portal.attach, as it returns a typed result
instead of dynamic.
Implementation
@override
Future<Object> attach(Portal<Object> portal) =>
_delegatePortalHost.attach(portal) as Future<Object>;