disabled property
- @HostBinding.new('class.disabled')
- @HostBinding.new('attr.aria-disabled')
- @Input.new()
getter/setter pairoverride
Whether the checkbox should not respond to events, and have a style that suggests that interaction is not allowed.
Implementation
@HostBinding('class.disabled')
@HostBinding('attr.aria-disabled')
@Input()
bool disabled = false;