maxCalendarSizePx property
The maximum height to give to the entire calendar scroller. If adding padding due to scrolling would cause the calendar to get taller than this, we'll trim some off the top or bottom to fit into this limit.
This is an attempt to keep the scrollbar even a little bit useful... let's see if it helps any.
Implementation
static final int maxCalendarSizePx = 20000;