preferredPositions property

  1. @Input.new()
Iterable? preferredPositions
getter/setter pair

Preferred positions to pass to the material popup component.

For the meaning of this parameter, see the PopupInterface documentation.

Implementation

@Input()
Iterable? preferredPositions;