showButtonBorder property
bool
get
showButtonBorder
Implementation
bool get showButtonBorder {
if (_showButtonBorder != null) return _showButtonBorder!;
// If the input field is not specified, maitain backwards compatible
// behavior, which decides based on whether the text is null.
return buttonText != null;
}
Whether to show the bottom border of the dropdown button.
Implementation
@Input()
set showButtonBorder(bool value) {
_showButtonBorder = value;
}