onCancel property
The callback which is called when the stream is canceled.
May be set to null, in which case no callback will happen.
Implementation
@override
FutureOr<void> Function()? get onCancel => _initializeLazy().onCancel;
The callback which is called when the stream is canceled.
May be set to null, in which case no callback will happen.
Implementation
@override
set onCancel(FutureOr<void> Function()? onCancelHandler) {
_initializeLazy().onCancel = onCancelHandler;
}